@@ -16,6 +16,14 @@ from microtc.utils import load_model
 
 
 class Country(object):
+    """
+    Obtain the country from a text.
+
+    >>> from text_models.place import Country
+    >>> cntr = Country()
+    >>> cntr.country("I live in Mexico.")
+    'MX'
+    """
     def __init__(self):
         self._country = load_model(download("country.ds"))
         self._location = load_model(download("country-loc.ds"))
@@ -31,21 +39,33 @@ class Country(object):
 
         res = self._country.klass(text)
         if len(res) == 1:
-            return list(res)[0]
+            cc = list(res)[0]
+            if len(cc) == 2:
+                return cc
         res2 = self._location.klass(text)
         if len(res2) == 1:
-            return list(res2)[0]
+            cc = list(res2)[0]
+            if len(cc) == 2:
+                return cc
         r = res.intersection(res2)
         if len(r) == 1:
-            return list(r)[0]
+            cc = list(r)[0]
+            if len(cc) == 2:
+                return cc
         return None
 
 
     def country_from_twitter(self, tw):
+        """
+        Identify the country from a tweet.
+
+        :param tw: Tweet
+        :type tw: dict
+        """
         place = tw.get("place", None)
         if place is None:
             return self.country(tw["user"]["location"])
         country_code = place.get("country_code")
-        if country_code is None:
+        if country_code is None or len(country_code) < 2:
             return self.country(tw["user"]["location"])
-        return country_code
\ No newline at end of file
+        return country_code
